summaryrefslogtreecommitdiffstats
path: root/src/ui/dialog/session-player.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/ui/dialog/session-player.cpp')
-rw-r--r--src/ui/dialog/session-player.cpp20
1 files changed, 15 insertions, 5 deletions
diff --git a/src/ui/dialog/session-player.cpp b/src/ui/dialog/session-player.cpp
index b378c0b5a..b9a44fd98 100644
--- a/src/ui/dialog/session-player.cpp
+++ b/src/ui/dialog/session-player.cpp
@@ -1,11 +1,10 @@
/**
* Whiteboard session playback control dialog
*
* Authors:
* David Yip <yipdw@rose-hulman.edu>
*
* Copyright (c) 2005 Authors
- *
* Released under GNU GPL, read the file 'COPYING' for more information
*/
@@ -228,3 +227,14 @@ SessionPlaybackDialogImpl::_respCallback(int resp)
}
}
+
+/*
+ Local Variables:
+ mode:c++
+ c-file-style:"stroustrup"
+ c-file-offsets:((innamespace . 0)(inline-open . 0)(case-label . +))
+ indent-tabs-mode:nil
+ fill-column:99
+ End:
+*/
+// vim: filetype=cpp:expandtab:shiftwidth=4:tabstop=8:softtabstop=4:encoding=utf-8:textwidth=99 :
@@ -1,11 +1,10 @@
-/**
- * Whiteboard session playback control dialog
- *
- * Authors:
+/** @file
+ * @brief Whiteboard session playback control dialog - implementation
+ */
+/* Authors:
* David Yip <yipdw@rose-hulman.edu>
*